@@ -62,11 +62,12 @@ def manageDatabases(username, repoPath):
         # print(database)
         dbPath = repoPath + database + '.sql'
         exportCmd = wrapperAdmin(scripts.exportDatabase(database, dbPath))
+        # print(exportCmd)
         utilum.system.shell(exportCmd)
         
-        # format sql dump
-        if(database not in ['mysql','sys','information_schema','performance_schema']):
-            formatter.process(fileReadPath = dbPath, fileWritePath = dbPath)
+        # format sql dump: skipping for now
+        # if(database not in ['mysql','sys','information_schema','performance_schema'] or database in ['mysql','sys']):
+            # formatter.process(fileReadPath = dbPath, fileWritePath = dbPath)
         
         # change to 777
         grantPermissionFile(dbPath)
